Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.CollectionNode) predicate.CollectionNode
- func CollectionID(v xid.ID) predicate.CollectionNode
- func CollectionIDContains(v xid.ID) predicate.CollectionNode
- func CollectionIDContainsFold(v xid.ID) predicate.CollectionNode
- func CollectionIDEQ(v xid.ID) predicate.CollectionNode
- func CollectionIDEqualFold(v xid.ID) predicate.CollectionNode
- func CollectionIDGT(v xid.ID) predicate.CollectionNode
- func CollectionIDGTE(v xid.ID) predicate.CollectionNode
- func CollectionIDHasPrefix(v xid.ID) predicate.CollectionNode
- func CollectionIDHasSuffix(v xid.ID) predicate.CollectionNode
- func CollectionIDIn(vs ...xid.ID) predicate.CollectionNode
- func CollectionIDLT(v xid.ID) predicate.CollectionNode
- func CollectionIDLTE(v xid.ID) predicate.CollectionNode
- func CollectionIDNEQ(v xid.ID) predicate.CollectionNode
- func CollectionIDNotIn(vs ...xid.ID) predicate.CollectionNode
- func CreatedAt(v time.Time) predicate.CollectionNode
- func CreatedAtEQ(v time.Time) predicate.CollectionNode
- func CreatedAtGT(v time.Time) predicate.CollectionNode
- func CreatedAtGTE(v time.Time) predicate.CollectionNode
- func CreatedAtIn(vs ...time.Time) predicate.CollectionNode
- func CreatedAtLT(v time.Time) predicate.CollectionNode
- func CreatedAtLTE(v time.Time) predicate.CollectionNode
- func CreatedAtNEQ(v time.Time) predicate.CollectionNode
- func CreatedAtNotIn(vs ...time.Time) predicate.CollectionNode
- func HasCollection() predicate.CollectionNode
- func HasCollectionWith(preds ...predicate.Collection) predicate.CollectionNode
- func HasNode() predicate.CollectionNode
- func HasNodeWith(preds ...predicate.Node) predicate.CollectionNode
- func MembershipType(v string) predicate.CollectionNode
- func MembershipTypeContains(v string) predicate.CollectionNode
- func MembershipTypeContainsFold(v string) predicate.CollectionNode
- func MembershipTypeEQ(v string) predicate.CollectionNode
- func MembershipTypeEqualFold(v string) predicate.CollectionNode
- func MembershipTypeGT(v string) predicate.CollectionNode
- func MembershipTypeGTE(v string) predicate.CollectionNode
- func MembershipTypeHasPrefix(v string) predicate.CollectionNode
- func MembershipTypeHasSuffix(v string) predicate.CollectionNode
- func MembershipTypeIn(vs ...string) predicate.CollectionNode
- func MembershipTypeLT(v string) predicate.CollectionNode
- func MembershipTypeLTE(v string) predicate.CollectionNode
- func MembershipTypeNEQ(v string) predicate.CollectionNode
- func MembershipTypeNotIn(vs ...string) predicate.CollectionNode
- func NodeID(v xid.ID) predicate.CollectionNode
- func NodeIDContains(v xid.ID) predicate.CollectionNode
- func NodeIDContainsFold(v xid.ID) predicate.CollectionNode
- func NodeIDEQ(v xid.ID) predicate.CollectionNode
- func NodeIDEqualFold(v xid.ID) predicate.CollectionNode
- func NodeIDGT(v xid.ID) predicate.CollectionNode
- func NodeIDGTE(v xid.ID) predicate.CollectionNode
- func NodeIDHasPrefix(v xid.ID) predicate.CollectionNode
- func NodeIDHasSuffix(v xid.ID) predicate.CollectionNode
- func NodeIDIn(vs ...xid.ID) predicate.CollectionNode
- func NodeIDLT(v xid.ID) predicate.CollectionNode
- func NodeIDLTE(v xid.ID) predicate.CollectionNode
- func NodeIDNEQ(v xid.ID) predicate.CollectionNode
- func NodeIDNotIn(vs ...xid.ID) predicate.CollectionNode
- func Not(p predicate.CollectionNode) predicate.CollectionNode
- func Or(predicates ...predicate.CollectionNode) predicate.CollectionNode
- func ValidColumn(column string) bool
- type OrderOption
- func ByCollectionField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByCollectionID(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByMembershipType(opts ...sql.OrderTermOption) OrderOption
- func ByNodeField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByNodeID(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the collectionnode type in the database. Label = "collection_node" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldCollectionID holds the string denoting the collection_id field in the database. FieldCollectionID = "collection_id" // FieldNodeID holds the string denoting the node_id field in the database. FieldNodeID = "node_id" // FieldMembershipType holds the string denoting the membership_type field in the database. FieldMembershipType = "membership_type" // EdgeCollection holds the string denoting the collection edge name in mutations. EdgeCollection = "collection" // EdgeNode holds the string denoting the node edge name in mutations. EdgeNode = "node" // CollectionFieldID holds the string denoting the ID field of the Collection. CollectionFieldID = "id" // NodeFieldID holds the string denoting the ID field of the Node. NodeFieldID = "id" // Table holds the table name of the collectionnode in the database. Table = "collection_nodes" // CollectionTable is the table that holds the collection relation/edge. CollectionTable = "collection_nodes" // CollectionInverseTable is the table name for the Collection entity. // It exists in this package in order to avoid circular dependency with the "collection" package. CollectionInverseTable = "collections" // CollectionColumn is the table column denoting the collection relation/edge. CollectionColumn = "collection_id" // NodeTable is the table that holds the node relation/edge. NodeTable = "collection_nodes" // NodeInverseTable is the table name for the Node entity. // It exists in this package in order to avoid circular dependency with the "node" package. NodeInverseTable = "nodes" // NodeColumn is the table column denoting the node relation/edge. NodeColumn = "node_id" )
Variables ¶
var ( // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultCollectionID holds the default value on creation for the "collection_id" field. DefaultCollectionID func() xid.ID // CollectionIDValidator is a validator for the "collection_id" field. It is called by the builders before save. CollectionIDValidator func(string) error // DefaultNodeID holds the default value on creation for the "node_id" field. DefaultNodeID func() xid.ID // NodeIDValidator is a validator for the "node_id" field. It is called by the builders before save. NodeIDValidator func(string) error // DefaultMembershipType holds the default value on creation for the "membership_type" field. DefaultMembershipType string )
var Columns = []string{ FieldCreatedAt, FieldCollectionID, FieldNodeID, FieldMembershipType, }
Columns holds all SQL columns for collectionnode fields.
Functions ¶
func And ¶
func And(predicates ...predicate.CollectionNode) predicate.CollectionNode
And groups predicates with the AND operator between them.
func CollectionID ¶
func CollectionID(v xid.ID) predicate.CollectionNode
CollectionID applies equality check predicate on the "collection_id" field. It's identical to CollectionIDEQ.
func CollectionIDContains ¶
func CollectionIDContains(v xid.ID) predicate.CollectionNode
CollectionIDContains applies the Contains predicate on the "collection_id" field.
func CollectionIDContainsFold ¶
func CollectionIDContainsFold(v xid.ID) predicate.CollectionNode
CollectionIDContainsFold applies the ContainsFold predicate on the "collection_id" field.
func CollectionIDEQ ¶
func CollectionIDEQ(v xid.ID) predicate.CollectionNode
CollectionIDEQ applies the EQ predicate on the "collection_id" field.
func CollectionIDEqualFold ¶
func CollectionIDEqualFold(v xid.ID) predicate.CollectionNode
CollectionIDEqualFold applies the EqualFold predicate on the "collection_id" field.
func CollectionIDGT ¶
func CollectionIDGT(v xid.ID) predicate.CollectionNode
CollectionIDGT applies the GT predicate on the "collection_id" field.
func CollectionIDGTE ¶
func CollectionIDGTE(v xid.ID) predicate.CollectionNode
CollectionIDGTE applies the GTE predicate on the "collection_id" field.
func CollectionIDHasPrefix ¶
func CollectionIDHasPrefix(v xid.ID) predicate.CollectionNode
CollectionIDHasPrefix applies the HasPrefix predicate on the "collection_id" field.
func CollectionIDHasSuffix ¶
func CollectionIDHasSuffix(v xid.ID) predicate.CollectionNode
CollectionIDHasSuffix applies the HasSuffix predicate on the "collection_id" field.
func CollectionIDIn ¶
func CollectionIDIn(vs ...xid.ID) predicate.CollectionNode
CollectionIDIn applies the In predicate on the "collection_id" field.
func CollectionIDLT ¶
func CollectionIDLT(v xid.ID) predicate.CollectionNode
CollectionIDLT applies the LT predicate on the "collection_id" field.
func CollectionIDLTE ¶
func CollectionIDLTE(v xid.ID) predicate.CollectionNode
CollectionIDLTE applies the LTE predicate on the "collection_id" field.
func CollectionIDNEQ ¶
func CollectionIDNEQ(v xid.ID) predicate.CollectionNode
CollectionIDNEQ applies the NEQ predicate on the "collection_id" field.
func CollectionIDNotIn ¶
func CollectionIDNotIn(vs ...xid.ID) predicate.CollectionNode
CollectionIDNotIn applies the NotIn predicate on the "collection_id" field.
func CreatedAt ¶
func CreatedAt(v time.Time) predicate.CollectionNode
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
func CreatedAtEQ(v time.Time) predicate.CollectionNode
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
func CreatedAtGT(v time.Time) predicate.CollectionNode
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
func CreatedAtGTE(v time.Time) predicate.CollectionNode
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
func CreatedAtIn(vs ...time.Time) predicate.CollectionNode
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
func CreatedAtLT(v time.Time) predicate.CollectionNode
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
func CreatedAtLTE(v time.Time) predicate.CollectionNode
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
func CreatedAtNEQ(v time.Time) predicate.CollectionNode
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
func CreatedAtNotIn(vs ...time.Time) predicate.CollectionNode
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func HasCollection ¶
func HasCollection() predicate.CollectionNode
HasCollection applies the HasEdge predicate on the "collection" edge.
func HasCollectionWith ¶
func HasCollectionWith(preds ...predicate.Collection) predicate.CollectionNode
HasCollectionWith applies the HasEdge predicate on the "collection" edge with a given conditions (other predicates).
func HasNode ¶
func HasNode() predicate.CollectionNode
HasNode applies the HasEdge predicate on the "node" edge.
func HasNodeWith ¶
func HasNodeWith(preds ...predicate.Node) predicate.CollectionNode
HasNodeWith applies the HasEdge predicate on the "node" edge with a given conditions (other predicates).
func MembershipType ¶
func MembershipType(v string) predicate.CollectionNode
MembershipType applies equality check predicate on the "membership_type" field. It's identical to MembershipTypeEQ.
func MembershipTypeContains ¶
func MembershipTypeContains(v string) predicate.CollectionNode
MembershipTypeContains applies the Contains predicate on the "membership_type" field.
func MembershipTypeContainsFold ¶
func MembershipTypeContainsFold(v string) predicate.CollectionNode
MembershipTypeContainsFold applies the ContainsFold predicate on the "membership_type" field.
func MembershipTypeEQ ¶
func MembershipTypeEQ(v string) predicate.CollectionNode
MembershipTypeEQ applies the EQ predicate on the "membership_type" field.
func MembershipTypeEqualFold ¶
func MembershipTypeEqualFold(v string) predicate.CollectionNode
MembershipTypeEqualFold applies the EqualFold predicate on the "membership_type" field.
func MembershipTypeGT ¶
func MembershipTypeGT(v string) predicate.CollectionNode
MembershipTypeGT applies the GT predicate on the "membership_type" field.
func MembershipTypeGTE ¶
func MembershipTypeGTE(v string) predicate.CollectionNode
MembershipTypeGTE applies the GTE predicate on the "membership_type" field.
func MembershipTypeHasPrefix ¶
func MembershipTypeHasPrefix(v string) predicate.CollectionNode
MembershipTypeHasPrefix applies the HasPrefix predicate on the "membership_type" field.
func MembershipTypeHasSuffix ¶
func MembershipTypeHasSuffix(v string) predicate.CollectionNode
MembershipTypeHasSuffix applies the HasSuffix predicate on the "membership_type" field.
func MembershipTypeIn ¶
func MembershipTypeIn(vs ...string) predicate.CollectionNode
MembershipTypeIn applies the In predicate on the "membership_type" field.
func MembershipTypeLT ¶
func MembershipTypeLT(v string) predicate.CollectionNode
MembershipTypeLT applies the LT predicate on the "membership_type" field.
func MembershipTypeLTE ¶
func MembershipTypeLTE(v string) predicate.CollectionNode
MembershipTypeLTE applies the LTE predicate on the "membership_type" field.
func MembershipTypeNEQ ¶
func MembershipTypeNEQ(v string) predicate.CollectionNode
MembershipTypeNEQ applies the NEQ predicate on the "membership_type" field.
func MembershipTypeNotIn ¶
func MembershipTypeNotIn(vs ...string) predicate.CollectionNode
MembershipTypeNotIn applies the NotIn predicate on the "membership_type" field.
func NodeID ¶
func NodeID(v xid.ID) predicate.CollectionNode
NodeID applies equality check predicate on the "node_id" field. It's identical to NodeIDEQ.
func NodeIDContains ¶
func NodeIDContains(v xid.ID) predicate.CollectionNode
NodeIDContains applies the Contains predicate on the "node_id" field.
func NodeIDContainsFold ¶
func NodeIDContainsFold(v xid.ID) predicate.CollectionNode
NodeIDContainsFold applies the ContainsFold predicate on the "node_id" field.
func NodeIDEQ ¶
func NodeIDEQ(v xid.ID) predicate.CollectionNode
NodeIDEQ applies the EQ predicate on the "node_id" field.
func NodeIDEqualFold ¶
func NodeIDEqualFold(v xid.ID) predicate.CollectionNode
NodeIDEqualFold applies the EqualFold predicate on the "node_id" field.
func NodeIDGT ¶
func NodeIDGT(v xid.ID) predicate.CollectionNode
NodeIDGT applies the GT predicate on the "node_id" field.
func NodeIDGTE ¶
func NodeIDGTE(v xid.ID) predicate.CollectionNode
NodeIDGTE applies the GTE predicate on the "node_id" field.
func NodeIDHasPrefix ¶
func NodeIDHasPrefix(v xid.ID) predicate.CollectionNode
NodeIDHasPrefix applies the HasPrefix predicate on the "node_id" field.
func NodeIDHasSuffix ¶
func NodeIDHasSuffix(v xid.ID) predicate.CollectionNode
NodeIDHasSuffix applies the HasSuffix predicate on the "node_id" field.
func NodeIDIn ¶
func NodeIDIn(vs ...xid.ID) predicate.CollectionNode
NodeIDIn applies the In predicate on the "node_id" field.
func NodeIDLT ¶
func NodeIDLT(v xid.ID) predicate.CollectionNode
NodeIDLT applies the LT predicate on the "node_id" field.
func NodeIDLTE ¶
func NodeIDLTE(v xid.ID) predicate.CollectionNode
NodeIDLTE applies the LTE predicate on the "node_id" field.
func NodeIDNEQ ¶
func NodeIDNEQ(v xid.ID) predicate.CollectionNode
NodeIDNEQ applies the NEQ predicate on the "node_id" field.
func NodeIDNotIn ¶
func NodeIDNotIn(vs ...xid.ID) predicate.CollectionNode
NodeIDNotIn applies the NotIn predicate on the "node_id" field.
func Not ¶
func Not(p predicate.CollectionNode) predicate.CollectionNode
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.CollectionNode) predicate.CollectionNode
Or groups predicates with the OR operator between them.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the CollectionNode queries.
func ByCollectionField ¶
func ByCollectionField(field string, opts ...sql.OrderTermOption) OrderOption
ByCollectionField orders the results by collection field.
func ByCollectionID ¶
func ByCollectionID(opts ...sql.OrderTermOption) OrderOption
ByCollectionID orders the results by the collection_id field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByMembershipType ¶
func ByMembershipType(opts ...sql.OrderTermOption) OrderOption
ByMembershipType orders the results by the membership_type field.
func ByNodeField ¶
func ByNodeField(field string, opts ...sql.OrderTermOption) OrderOption
ByNodeField orders the results by node field.
func ByNodeID ¶
func ByNodeID(opts ...sql.OrderTermOption) OrderOption
ByNodeID orders the results by the node_id field.